pub struct SendResponseModel {Show 19 fields
pub object: Option<String>,
pub id: Option<Uuid>,
pub access_id: Option<String>,
pub type: Option<SendType>,
pub auth_type: Option<AuthType>,
pub name: Option<String>,
pub notes: Option<String>,
pub file: Option<Box<SendFileModel>>,
pub text: Option<Box<SendTextModel>>,
pub key: Option<String>,
pub max_access_count: Option<i32>,
pub access_count: Option<i32>,
pub password: Option<String>,
pub emails: Option<String>,
pub disabled: Option<bool>,
pub revision_date: Option<String>,
pub expiration_date: Option<String>,
pub deletion_date: Option<String>,
pub hide_email: Option<bool>,
}Expand description
SendResponseModel : A response issued to a Bitwarden client in response to ownership operations.
Fields
object: Option<String>id: Option<Uuid>Identifies the send to its owner
access_id: Option<String>Identifies the send in a send URL
type: Option<SendType>auth_type: Option<AuthType>name: Option<String>Label for the send.
notes: Option<String>Notes for the send. This is only visible to the owner of the send. This field is encrypted.
file: Option<Box<SendFileModel>>text: Option<Box<SendTextModel>>key: Option<String>A base64-encoded byte array containing the Send’s encryption key. It’s also provided to send recipients in the Send’s URL.
max_access_count: Option<i32>The maximum number of times a send can be accessed before it expires. When this value is null, there is no limit.
access_count: Option<i32>The number of times a send has been accessed since it was created.
password: Option<String>Base64-encoded byte array of a password hash that grants access to the send. Mutually exclusive with Bit.Api.Tools.Models.Response.SendResponseModel.Emails.
emails: Option<String>Comma-separated list of emails that may access the send using OTP authentication. Mutually exclusive with Bit.Api.Tools.Models.Response.SendResponseModel.Password.
disabled: Option<bool>When true, send access is disabled.
revision_date: Option<String>The last time this send’s data changed.
expiration_date: Option<String>The date after which a send cannot be accessed. When this value is null, there is no expiration date.
deletion_date: Option<String>The date after which a send may be automatically deleted from the server.
hide_email: Option<bool>When true send access hides the user’s email address and displays a confirmation message instead.
Implementations
Sourceimpl SendResponseModel
impl SendResponseModel
Sourcepub fn new() -> SendResponseModel
pub fn new() -> SendResponseModel
A response issued to a Bitwarden client in response to ownership operations.